@@ -1,11 +1,13 @@
 package Sah::Schema::color::rgb24;
 
-our $DATE = '2017-12-03'; # DATE
-our $VERSION = '0.001'; # VERSION
+our $DATE = '2019-07-25'; # DATE
+our $VERSION = '0.003'; # VERSION
 
 our $schema = [str => {
     summary => 'RGB 24-digit color, a hexdigit e.g. ffcc00', # XXX also allow other forms
     match => qr/\A[0-9A-Fa-f]{6}\z/,
+    'x.completion' => ['colorname'],
+    'x.perl.coerce_rules' => ['str_rgb24_from_colorname_X_or_code'],
 }, {}];
 
 1;
@@ -23,7 +25,21 @@ Sah::Schema::color::rgb24 - RGB 24-digit color, a hexdigit e.g. ffcc00
 
 =head1 VERSION
 
-This document describes version 0.001 of Sah::Schema::color::rgb24 (from Perl distribution Sah-Schemas-Color), released on 2017-12-03.
+This document describes version 0.003 of Sah::Schema::color::rgb24 (from Perl distribution Sah-Schemas-Color), released on 2019-07-25.
+
+=head1 DESCRIPTION
+
+Accepts color codes (with optional pound sign prefix, which will be removed), e.g.:
+
+ ffff00
+ #80FF00
+
+Color names (from L<Graphics::ColorNames::X>) are also accepted and will be
+coerced to its RGB code, e.g.:
+
+ black
+
+(will be coerced to C<000000>)
 
 =head1 HOMEPAGE
 
@@ -47,7 +63,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2017 by perlancar@cpan.org.
+This software is copyright (c) 2019, 2018, 2017 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
